Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ContextValue ¶
ContextValue provides an action that sets the given value into the context. The only supported type is *Workspace.
func Fmt ¶
func Fmt(paramsopt ...FormatParams) cli.Action
Fmt returns an action which formats source. The parameters specify which files to format. When the parameters are not specified, the parameters are gathered from the action's context. Also when the parameters are not specified, the action contains an initializer that contains args and flags meant to provide useful default configuration.
func ListDevices ¶
func ListDevices(detailedopt ...bool) cli.Action
ListDevices provides an action which prints out the information about devices. If present, detailedopt controls the verbosity. When not present, a flag --verbose is consulted to control it
Types ¶
type CheckParams ¶
type FormatParams ¶
type Workspace ¶
type Workspace struct {
cli.Action
*joeconfig.Workspace
Directory string
Allocator *automation.Allocator
// contains filtered or unexported fields
}
func FromContext ¶
FromContext gets the Workspace from the context otherwise panics
func (*Workspace) AutogunDir ¶
AutogunDir gets the directory where workspace metadata is stored
func (*Workspace) EnsureAllocator ¶
func (w *Workspace) EnsureAllocator() *automation.Allocator
TODO This should not be API
func (*Workspace) Load ¶
Load scans the workspace for configuration files and builds a Model from the automations they declare.
func (*Workspace) Model ¶
Model obtains the model for the workspace. This method implicitly loads the workspace and panics when the workspace cannot be loaded. Investigate Workspace.Load to load while handling load errors